==> dasu_4.11.jar: edu/northwestern/dasu/dynamic/drools/FactTraceResult.java <==
/**
 * Dasu Project
 *
 * File:         FactTraceResult.java
 * RCS:          $Id$
 * Description:  FactTraceResult class (see below)
 * Author:       Mario Sanchez
 *               Northwestern Systems Research Group
 *               Department of Computer Science
 *               Northwestern University
 * Created:      May 31, 2010 at 5:15:48 PM
 * Language:     Java
 * Package:      edu.northwestern.dasu.drools
 * Status:       Experimental (Do Not Distribute)
 *
 * (C) Copyright 2010, Northwestern University, all rights reserved.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 */
package edu.northwestern.dasu.dynamic.drools;

import java.util.ArrayList;

import edu.northwestern.dasu.drools.FactProbeResult;
import edu.northwestern.dasu.measurement.TraceEntry;
import edu.northwestern.dasu.measurement.types.ProbeType;
import edu.northwestern.dasu.util.Util;


/**
 * @author Mario Sanchez &lt;msanchez@eecs.northwestern.edu&gt;
 *
 * The FactTraceResult class  
 * For an member to be visible to Drools (as part of the fact)  
 * it must have it's own public setter and getter functions
 */

public class FactTraceResult extends FactProbeResult {
	
	public FactTraceResult() {
		super(ProbeType.TRACEROUTE);
	}

	/**
	 * 
	 */
	private static final long serialVersionUID = 1L;
	public String source;
	public String dest;
	public ArrayList<TraceEntry> entries;
	public long timestamp = Util.currentGMTTime();
	public int destType;
	public int taskId = -1;
	public String target;
	
	public String getSource() {
		return source;
	}

	public String getDest() {
		return dest;
	}

	public ArrayList<TraceEntry> getEntries() {
		return entries;
	}

	public long getTimestamp() {
		return timestamp;
	}

	public int getDestType() {
		return destType;
	}

	public void setSource(String source) {
		String temp = this.source;
		this.source = source;
        pcs.firePropertyChange("source", new String(temp), new String(source));
	}

	public void setDest(String dest) {
        String temp = this.dest;
		this.dest = dest;
        pcs.firePropertyChange("dest", new String(temp), new String(dest));
	}

	public void setEntries(ArrayList<TraceEntry> entries) {
		ArrayList<TraceEntry> temp = this.entries;
		this.entries = entries;
        pcs.firePropertyChange("entries", new ArrayList<TraceEntry>(temp), new ArrayList<TraceEntry>(entries));
	}

	public void setTimestamp(long timestamp) {
		Long temp = this.timestamp;
		this.timestamp = timestamp;
        pcs.firePropertyChange("timestamp", new Long(temp), new Long(timestamp));
	}

	public void setDestType(int destType) {
		Integer temp = this.destType;
		this.destType = destType;
        pcs.firePropertyChange("destType", new Integer(temp), new Integer(destType));

	}
	
	public void setTarget(String target) {
		this.target = target;
	}
	
	public String getTarget() {
		return target;
	}
	
}

==> dasu_5.31.jar: edu/northwestern/dasu/dynamic/drools/FactTraceResult.java <==
/**
 * Dasu Project
 *
 * File:         FactTraceResult.java
 * RCS:          $Id$
 * Description:  FactTraceResult class (see below)
 * Author:       Mario Sanchez
 *               Northwestern Systems Research Group
 *               Department of Computer Science
 *               Northwestern University
 * Created:      May 31, 2010 at 5:15:48 PM
 * Language:     Java
 * Package:      edu.northwestern.dasu.drools
 * Status:       Experimental (Do Not Distribute)
 *
 * (C) Copyright 2010, Northwestern University, all rights reserved.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 */
package edu.northwestern.dasu.dynamic.drools;

import java.util.ArrayList;

import edu.northwestern.cs.aqualab.cattle.jsonsimple.JSONArray;
import edu.northwestern.cs.aqualab.cattle.jsonsimple.JSONObject;
import edu.northwestern.dasu.drools.FactProbeResult;
import edu.northwestern.dasu.measurement.TraceEntry;
import edu.northwestern.dasu.measurement.types.ProbeType;
import edu.northwestern.dasu.util.Util;


/**
 * @author Mario Sanchez &lt;msanchez@eecs.northwestern.edu&gt;
 *
 * The FactTraceResult class  
 * For an member to be visible to Drools (as part of the fact)  
 * it must have it's own public setter and getter functions
 */

public class FactTraceResult extends FactProbeResult {
	
	public FactTraceResult() {
		super(ProbeType.valueOf("TRACEROUTE"));
	}

	private static final long serialVersionUID = 1L;
	public String source;
	public String dest;
	public ArrayList<TraceEntry> entries;
	public long timestamp = Util.currentGMTTime();
	public int destType;
	public int taskId = -1;
	public String target;
	
	public String getSource() {
		return source;
	}

	public String getDest() {
		return dest;
	}

	public ArrayList<TraceEntry> getEntries() {
		return entries;
	}

	public long getTimestamp() {
		return timestamp;
	}

	public int getDestType() {
		return destType;
	}

	public void setSource(String source) {
		String temp = this.source;
		this.source = source;
        pcs.firePropertyChange("source", new String(temp), new String(source));
	}

	public void setDest(String dest) {
        String temp = this.dest;
		this.dest = dest;
        pcs.firePropertyChange("dest", new String(temp), new String(dest));
	}

	public void setEntries(ArrayList<TraceEntry> entries) {
		ArrayList<TraceEntry> temp = this.entries;
		this.entries = entries;
        pcs.firePropertyChange("entries", new ArrayList<TraceEntry>(temp), new ArrayList<TraceEntry>(entries));
	}

	public void setTimestamp(long timestamp) {
		Long temp = this.timestamp;
		this.timestamp = timestamp;
        pcs.firePropertyChange("timestamp", new Long(temp), new Long(timestamp));
	}

	public void setDestType(int destType) {
		Integer temp = this.destType;
		this.destType = destType;
        pcs.firePropertyChange("destType", new Integer(temp), new Integer(destType));

	}
	
	public void setTarget(String target) {
		this.target = target;
	}
	
	public String getTarget() {
		return target;
	}
	
	public JSONObject toJSON() {

		JSONObject json = super.toJSON();
		json.remove("entries");
		JSONArray arr = new JSONArray();		
		for ( TraceEntry te : entries ) {
			arr.add(te.toJSON());
		}
		json.put("entries", arr);
		return json;
	}

	
}
